import { createI18n } from "vue-i18n";

import de from "@/i18n/de";
import en from "@/i18n/en";

export const def = {
  de: de,
  en: en,
};

/**
 * Represents the schema of localized messages.
 *
 * @remarks
 * This type is derived from the default English localization
 * and provides a structure for all defined messages.
 */
type I18nMessageSchema = typeof en;

const i18n = createI18n<I18nMessageSchema, "en" | "de">({
  locale: localStorage.getItem("coscine.locale")?.toString(),
  fallbackLocale: "en",
  messages: def,
  globalInjection: true,
  silentFallbackWarn: true,
  legacy: false,
});

export default i18n;
